Function caesar_core::receiver::start_receiver
source · pub async fn start_receiver(
filepath: String,
relay: &str,
name: &str
) -> Result<()>Expand description
Start the receiver process.
This function initiates the receiver process by performing the following steps:
- Replaces the protocol of the given
relayURL. - Downloads the room information from the server.
- Connects to the local or relay server based on the platform.
- Downloads the file from the server.
Arguments
filepath- The path to the file to be received.relay- The URL of the relay server.name- The name of the receiver.
Returns
Returns a Result indicating the success or failure of the receiver process.